package com.uas.platform.warehouse.backend.api;

import com.uas.platform.warehouse.backend.dao.ErrorLogDao;
import com.uas.platform.warehouse.backend.service.CommonService;
import com.uas.platform.warehouse.backend.service.ShipmentService;
import com.uas.platform.warehouse.backend.transport.entity.BaseReply;
import com.uas.platform.warehouse.backend.transport.entity.PostBack;
import com.uas.platform.warehouse.backend.transport.service.NotificationService;
import com.uas.platform.warehouse.backend.transport.service.PullDataService;
import com.uas.platform.warehouse.core.common.ResultBean;
import com.uas.platform.warehouse.core.domain.VoucherType;
import com.uas.platform.warehouse.core.util.JacksonUtils;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Pageable;
import org.springframework.data.web.PageableDefault;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * Http interface for operating voucher notification.
 *
 * @author huxz
 */
@RestController
@RequestMapping(value = "/api")
public class NotificationController {

  private final ErrorLogDao logDao;

  private final NotificationService notificationService;

  private final ShipmentService shipmentService;

  private final PullDataService pullDataService;

  private final CommonService commonService;

  @Autowired
  public NotificationController(
      ErrorLogDao logDao, ShipmentService shipmentService,
      PullDataService pullDataService,
      NotificationService notificationService,
      CommonService commonService) {
    this.logDao = logDao;
    this.shipmentService = shipmentService;
    this.pullDataService = pullDataService;
    this.notificationService = notificationService;
    this.commonService = commonService;
  }

  /**
   * Common api for post data to b2b
   * @param datas List json data
   * @return
   */
  @PostMapping(value = "/post", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
  public  ResultBean<Map<String,Object>> postToB2bCommon( @RequestBody List<Map> datas) {
    String type,data;
    System.out.println(datas);
    Map<String,Object> respMap = new HashMap<String,Object>();
    boolean status = false;
    for (Map map:datas){
      if(map.get("type")!=null){
        type = map.get("type").toString();
        data = JacksonUtils.toJson(map);
        if("pull".equals(type)){ //出货单
          status = commonService.doShipment(data);
        }else if("asn".equals(type)){ //入库单
          status = commonService.doStockin(data);
        }else if("tran".equals(type)){ //调拨单
          status = commonService.doTransfer(data);
        }else if("reply".equals(type)){ //物流回复接口
          status = commonService.doNormalReply(data);
        }else if("item".equals(type)){ //物料资料
          status = commonService.doProduct(data);
        }else if("packing".equals(type)){ //包装单
          status = commonService.doPacking(data);
        }else if("packing-reply".equals(type)){ //包装单回复
          status = commonService.doPackingReply(data);
        }else if("invoice".equals(type)){ //发票单
          status = commonService.doInvoice(data);
        }else if("invoice-reply".equals(type)){//发票单回复
          status = commonService.doInvoiceReply(data);
        }else if("mainfest-reply".equals(type)){//出入库报关回复
          status = commonService.doProdioMainfestReply(data);
        }else if("prodmainfest-reply".equals(type)){//物料报关回复
          status = commonService.doProductMainfestReply(data);
        }else if("fee-reply".equals(type)){//费用回复
          status = commonService.doFeeReply(data);
        }
      }
    }
    respMap.put("success",status);
    return new ResultBean<Map<String,Object>>(respMap);
  }

  /**
   * Gain specific post back from warehouse by pagination.
   *
   * @param type  voucher type
   * @param pageInfo  pagination info
   * @return  response data using unified data format
   */
  @GetMapping(value = "/gain-notice-reply", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
  public ResultBean<List<BaseReply>> gainShipReplyNotice(VoucherType type,
                                                        @PageableDefault(size = 50) Pageable pageInfo) {
    return new ResultBean<List<BaseReply>>(pullDataService.gainReplyNotice(type, pageInfo));
  }
}
