package com.uas.platform.warehouse.backend.api;

import com.uas.platform.warehouse.backend.transport.entity.BaseVoucher;
import com.uas.platform.warehouse.backend.transport.entity.Status;
import com.uas.platform.warehouse.backend.transport.service.NotificationService;
import com.uas.platform.warehouse.backend.transport.service.PullDataService;
import com.uas.platform.warehouse.core.common.ResultBean;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.uas.platform.warehouse.core.util.JacksonUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Pageable;
import org.springframework.data.web.PageableDefault;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;

/**
 * Http interface for operating post back(reply).
 *
 * @author huxz
 */
@RestController
@RequestMapping(value = "/api")
public class ReplyController {

  private final NotificationService notificationService;

  private final PullDataService pullDataService;

  @Autowired
  public ReplyController(
      NotificationService notificationService,
      PullDataService pullDataService) {
    this.notificationService = notificationService;
    this.pullDataService = pullDataService;
  }

  /**
   * Gain specific notification from enterprise customer by pagination.
   *
   * @param pageInfo  pagination info
   * @return  response data using unified data format
   */
  @GetMapping(value = "/gain-notice", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
  public ResultBean<List<BaseVoucher>> gainNotificationFromEnterprise(
      @PageableDefault(size = 50) Pageable pageInfo) {
    return new ResultBean<List<BaseVoucher>>(pullDataService.gainNotificationFromEnterprise(pageInfo));
  }

  /**
   * 更新状态
   */
  @PostMapping(value = "/update-status", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
  public ResultBean<Map<String,Object>> updateStatus(@RequestBody List<Map> datas){
      Status status;
      boolean flag = true;
      Map<String,Object> respMap = new HashMap<String,Object>();
      System.out.println(datas);
      for (Map map : datas){
          status = JacksonUtils.fromJson(JacksonUtils.toJson(map),Status.class);
          if(!pullDataService.updateStatus(status)){
              flag = false;
          }
      }
      respMap.put("success",flag);
      return new ResultBean<Map<String,Object>>(respMap);
  }
}
