package com.uas.platform.warehouse.backend.config;

import com.uas.platform.warehouse.core.common.ResultBean;
import java.io.IOException;
import org.apache.log4j.Logger;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.http.converter.HttpMessageConverter;
import org.springframework.http.converter.HttpMessageNotReadableException;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.context.request.WebRequest;
import org.springframework.web.servlet.mvc.method.annotation.ResponseEntityExceptionHandler;

/**
 * Use @ControllerAdvice annotation to handler exceptions.
 *
 * <p>Tip: ResponseEntityExceptionHandler, write to the response with a {@link HttpMessageConverter
 * message converter}</p>
 *
 * @author huxz
 */
@ControllerAdvice(annotations = {RestController.class})
public class ControllerExceptionHandler extends ResponseEntityExceptionHandler {

  private static final Logger logger = Logger.getLogger(ControllerExceptionHandler.class);

  private static final String MESSAGE_BAD_REQUEST =
      HttpStatus.BAD_REQUEST.value() + " " + HttpStatus.BAD_REQUEST.getReasonPhrase();

  /**
   * Handler IOException and RuntimeException.
   *
   * @param ex  exception info
   * @return response entity
   */
  @ExceptionHandler(value = {IOException.class, RuntimeException.class})
  @ResponseBody
  public ResponseEntity<?> handlerCommonExceptions(Throwable ex) {
    logger.error("System Error occurs", ex);
    HttpHeaders headers = new HttpHeaders();
    headers.add("Content-Type", MediaType.APPLICATION_JSON_UTF8_VALUE);
    return new ResponseEntity<>(new ResultBean<>(ex), headers, HttpStatus.INTERNAL_SERVER_ERROR);
  }

  @Override
  protected ResponseEntity<Object> handleHttpMessageNotReadable(HttpMessageNotReadableException ex,
      HttpHeaders headers, HttpStatus status, WebRequest request) {
    logger.error(MESSAGE_BAD_REQUEST, ex);

    headers.add("Content-Type", MediaType.APPLICATION_JSON_UTF8_VALUE);
    return handleExceptionInternal(ex, new ResultBean<>(ex), headers, status, request);
  }
}
