package com.uas.platform.warehouse.backend.entity;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.uas.platform.warehouse.backend.transport.entity.BaseReply;
import com.uas.platform.warehouse.core.domain.VoucherType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * 用于通用的出入库单据回复.
 *
 * @author huxz
 */
@Entity
@Table(name = "normal_reply")
@JsonInclude(Include.NON_EMPTY)
public class NormalReply extends BaseReply {

  private static final long serialVersionUID = 772065983331719579L;

  @Id
  @GeneratedValue
  @Column(name = "id")
  @JsonIgnore
  private Long id;

  /**
   * 单号.
   */
  @Column(name = "voucher_no")
  private String no;

  /**
   * 回复状态.
   */
  @Column(name = "resp_state")
  private NormalReply.RespState state;

  /**
   * 备注.
   */
  @Column(name = "remark",columnDefinition = "TEXT")
  private String remark;

  /**
   * 单据类型.
   */
  @Column(name = "doc_type")
  private String docType;

  /**
   * 数据类型.
   */
  @Column(name = "type")
  private String type;

  /**
   * 仓储操作人.
   */
  @Column(name = "operator")
  private String operator;

  /**
   * 接收方UU.
   */
  @Column(name = "receiver_uu")
  @JsonProperty(access = JsonProperty.Access.WRITE_ONLY)
  private String receiverUU;

  /**
   * 发送方UU.
   */
  @Column(name = "sender_uu")
  private String senderUU;

  /**
   * 企业名称.
   */
  @Column(name = "en_name")
  @JsonProperty(access = JsonProperty.Access.WRITE_ONLY)
  private String enterprise;

  /**
   * 备用字段1.
   */
  @Column(name = "attribute1",columnDefinition = "TEXT")
  private String attribute1;

  /**
   * 备用字段2.
   */
  @Column(name = "attribute2",columnDefinition = "TEXT")
  private String attribute2;

  /**
   * 备用字段3.
   */
  @Column(name = "attribute3",columnDefinition = "TEXT")
  private String attribute3;

  /**
   *物流时间
   */
  @Column(name = "logisticstime")
  private Date logisticstime;
  /**
   * 物流地址
   */
  @Column(name = "logisticsaddr")
  private String logisticsaddr;
  /**
   * 物流备注
   */
  @Column(name = "logisticsremark")
  private String logisticsremark;

  public String getLogisticsremark() {
    return logisticsremark;
  }

  public void setLogisticsremark(String logisticsremark) {
    this.logisticsremark = logisticsremark;
  }

  public Long getId() {
    return id;
  }

  public void setId(Long id) {
    this.id = id;
  }

  public String getNo() {
    return no;
  }

  public void setNo(String no) {
    this.no = no;
  }

  public RespState getState() {
    return state;
  }

  public void setState(RespState state) {
    this.state = state;
  }

  public String getDocType() {
    return docType;
  }

  public void setDocType(String docType) {
    this.docType = docType;
  }

  public String getOperator() {
    return operator;
  }

  public void setOperator(String operator) {
    this.operator = operator;
  }

  public Date getLogisticstime() {
    return logisticstime;
  }

  public void setLogisticstime(Date logisticstime) {
    this.logisticstime = logisticstime;
  }

  public String getLogisticsaddr() {
    return logisticsaddr;
  }

  public void setLogisticsaddr(String logisticsaddr) {
    this.logisticsaddr = logisticsaddr;
  }

  @Override

  public String getReceiverUU() {
    return receiverUU;
  }

  public void setReceiverUU(String receiverUU) {
    this.receiverUU = receiverUU;
  }

  public String getSenderUU() {
    return senderUU;
  }

  public void setSenderUU(String senderUU) {
    this.senderUU = senderUU;
  }

  public String getEnterprise() {
    return enterprise;
  }

  public void setEnterprise(String enterprise) {
    this.enterprise = enterprise;
  }

  public String getType() {
    return type;
  }

  public void setType(String type) {
    this.type = type;
  }

  public String getAttribute1() {
    return attribute1;
  }

  public void setAttribute1(String attribute1) {
    this.attribute1 = attribute1;
  }

  public String getAttribute2() {
    return attribute2;
  }

  public void setAttribute2(String attribute2) {
    this.attribute2 = attribute2;
  }

  public String getAttribute3() {
    return attribute3;
  }

  public void setAttribute3(String attribute3) {
    this.attribute3 = attribute3;
  }

  public String getRemark() {
    return remark;
  }

  public void setRemark(String remark) {
    this.remark = remark;
  }

  /**
   * 出货回传回复类型.
   */
  public enum RespState {
    /**
     * 表示已收到
     */
    GET,
    /**
     * 表示已接单
     */
    RECEIVE,
    /**
     * 表示已到港
     */
    OUT,
    /**
     * 表示出货成功状态.
     */
    OK,
    /**
     * 表示出货失败状态.
     */
    NG
  }
}
