package com.uas.platform.warehouse.backend.entity;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.uas.platform.warehouse.backend.transport.entity.BaseVoucher;
import com.uas.platform.warehouse.core.util.JacksonUtils;
import java.util.Date;
import java.util.List;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToMany;
import javax.persistence.Table;

/**
 * 出货单信息.
 *
 * @author huxz
 */
@Entity
@Table(name = "shipment")
@JsonInclude(Include.NON_EMPTY)
public class Shipment extends BaseVoucher {

  @Id
  @GeneratedValue
  @Column(name = "id")
  @JsonIgnore
  private long id;

  /**
   * 仓库地址
   */
  @Column(name = "location")
  private String location;

  /**
   * 出货单号.
   */
  @Column(name = "pull_no")
  private String pullNo;

  /**
   * 出货类型.
   */
  @Column(name = "pull_type")
  private String pullType;

  /**
   * 预出货日期.
   */
  @Column(name = "predate")
  private Date predate;

  /**
   * 客户编号.
   */
  @Column(name = "cust_code")
  private String custCode;

  /**
   * 客户UU
   */
  @Column(name = "cust_uu")
  private String custUU;

  /**
   * 收货地址.
   */
  @Column(name = "address")
  private String address;

  /**
   * 联系人电话.
   */
  @Column(name = "phone")
  private String phone;

    /**
   * 包装单号.
   */
  @Column(name = "packing_no")
  private String packingNo;

  /**
   * 联系人地址.
   */
  @Column(name = "contact")
  private String contact;

  /**
   * 装箱单要求.
   */
  @Column(name = "pack_request",columnDefinition = "TEXT")
  private String packRequest;

  /**
   * 发票要求.
   */
  @Column(name = "invoice_request",columnDefinition = "TEXT")
  private String invoiceRequest;

  /**
   * 发货说明.
   */
  @Column(name = "delivery_note",columnDefinition = "TEXT")
  private String deliveryNote;

  /**
   * 备注.
   */
  @Column(name = "remark",columnDefinition = "TEXT")
  private String remark;

  /**
   * 录入人.
   */
  @Column(name = "operator")
  private String operator;

  /**
   * 发票号.
   */
  @Column(name = "invoice_no")
  private String invoiceNo;



  /**
   * 出货单明细.
   */
  @OneToMany(cascade = CascadeType.ALL, fetch = FetchType.EAGER)
  @JoinColumn(name = "shipment_id")
  private List<ShipmentDetail> details;

  public Shipment() {   }

  public String getPhone() {
    return phone;
  }

  public void setPhone(String phone) {
    this.phone = phone;
  }

  public String getPackingNo() {
    return packingNo;
  }

  public void setPackingNo(String packingNo) {
    this.packingNo = packingNo;
  }

  public long getId() {
    return id;
  }

  public void setId(long id) {
    this.id = id;
  }

  public String getPullNo() {
    return pullNo;
  }

  public void setPullNo(String pullNo) {
    this.pullNo = pullNo;
  }

  public String getPullType() {
    return pullType;
  }

  public void setPullType(String pullType) {
    this.pullType = pullType;
  }

  public Date getPredate() {
    return predate;
  }

  public void setPredate(Date predate) {
    this.predate = predate;
  }

  public String getCustCode() {
    return custCode;
  }

  public void setCustCode(String custCode) {
    this.custCode = custCode;
  }

  public String getAddress() {
    return address;
  }

  public void setAddress(String address) {
    this.address = address;
  }

  public String getContact() {
    return contact;
  }

  public void setContact(String contact) {
    this.contact = contact;
  }

  public String getPackRequest() {
    return packRequest;
  }

  public void setPackRequest(String packRequest) {
    this.packRequest = packRequest;
  }

  public String getInvoiceRequest() {
    return invoiceRequest;
  }

  public void setInvoiceRequest(String invoiceRequest) {
    this.invoiceRequest = invoiceRequest;
  }

  public String getDeliveryNote() {
    return deliveryNote;
  }

  public void setDeliveryNote(String deliveryNote) {
    this.deliveryNote = deliveryNote;
  }

  public String getRemark() {
    return remark;
  }

  public void setRemark(String remark) {
    this.remark = remark;
  }

  public String getOperator() {
    return operator;
  }

  public void setOperator(String operator) {
    this.operator = operator;
  }

  public String getInvoiceNo() {
    return invoiceNo;
  }

  public void setInvoiceNo(String invoiceNo) {
    this.invoiceNo = invoiceNo;
  }


  public String getLocation() {
    return location;
  }

  public void setLocation(String location) {
    this.location = location;
  }

  public String getCustUU() {
    return custUU;
  }

  public void setCustUU(String custUU) {
    this.custUU = custUU;
  }

  @Override
  public String toString() {
    return JacksonUtils.toJson(this);
  }

  public List<ShipmentDetail> getDetails() {
    return details;
  }

  public void setDetails(List<ShipmentDetail> details) {
    this.details = details;
  }
}
