package com.uas.platform.warehouse.backend.entity;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.uas.platform.warehouse.core.util.JacksonUtils;
import org.joda.time.LocalDateTime;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * 出货单明细，用于出货通知.
 *
 * @author huxz
 */
@Entity
@Table(name = "shipment_detail")
@JsonInclude(Include.NON_EMPTY)
public class ShipmentDetail {

  @Id
  @GeneratedValue
  @Column(name = "id")
  @JsonIgnore
  private Long id;

  /**
   * 出货单号.
   */
  @Column(name = "pull_no")
  private String pullNo;

  /**
   * 出货单行号.
   */
  @Column(name = "pull_line_no")
  private String pullLineNo;

  /**
   * 物料号.
   */
  @Column(name = "prod_code")
  private String pn;

  /**
   * 出货数量.
   */
  @Column(name = "out_qty")
  private int qty;

  /**
   * 批次号.
   */
  @Column(name = "batchCode")
  private String batchCode;

  /**
   * 客户物料号.
   */
  @Column(name = "cust_prod_code")
  private String custPn;


  /**
   * 客户PO号.
   */
  @Column(name = "po_code")
  private String poCode;

  /**
   * 客户型号.
   */
  @Column(name = "cust_prod_spec")
  private String custProdSpec;

  /**
   * 销售单价.
   */
  @Column(name = "sale_price")
  private Double salePrice;

  /**
   * 物料规格.
   */
  @Column(name = "spec")
  private String spec;

  /**
   * 采购币别.
   */
  @Column(name = "pur_currency")
  private String purCurrency;

  /**
   * 备用字段1.最小包装
   */
  @Column(name = "attribute1",columnDefinition = "TEXT")
  private String attribute1;

  /**
   * 备用字段2.物料种类
   */
  @Column(name = "attribute2",columnDefinition = "TEXT")
  private String attribute2;

  /**
   * 备用字段3.物料品牌
   */
  @Column(name = "attribute3",columnDefinition = "TEXT")
  private String attribute3;

  /**
   * 备用字段4.单位
   */
  @Column(name = "attribute4",columnDefinition = "TEXT")
  private String attribute4;

  /**
   * 备用字段5.原厂型号
   */
  @Column(name = "attribute5",columnDefinition = "TEXT")
  private String attribute5;

  /**
   * 操作时间
   */
  @Column(name = "operate_time")
  @JsonIgnore
  private Date operateTime = LocalDateTime.now().toDate();

  public ShipmentDetail() {
  }

  public Long getId() {
    return id;
  }

  public void setId(Long id) {
    this.id = id;
  }

  public String getPullLineNo() {
    return pullLineNo;
  }

  public void setPullLineNo(String pullLineNo) {
    this.pullLineNo = pullLineNo;
  }

  public String getPn() {
    return pn;
  }

  public void setPn(String pn) {
    this.pn = pn;
  }

  public int getQty() {
    return qty;
  }

  public void setQty(int qty) {
    this.qty = qty;
  }

  public String getBatchCode() {
    return batchCode;
  }

  public void setBatchCode(String batchCode) {
    this.batchCode = batchCode;
  }

  public String getCustPn() {
    return custPn;
  }

  public void setCustPn(String custPn) {
    this.custPn = custPn;
  }

  public String getPoCode() {
    return poCode;
  }

  public void setPoCode(String poCode) {
    this.poCode = poCode;
  }

  public String getCustProdSpec() {
    return custProdSpec;
  }

  public void setCustProdSpec(String custProdSpec) {
    this.custProdSpec = custProdSpec;
  }

  public Double getSalePrice() {
    return salePrice;
  }

  public void setSalePrice(Double salePrice) {
    this.salePrice = salePrice;
  }

  public String getSpec() {
    return spec;
  }

  public void setSpec(String spec) {
    this.spec = spec;
  }

  public String getPullNo() {
    return pullNo;
  }

  public void setPullNo(String pullNo) {
    this.pullNo = pullNo;
  }

  public String getAttribute1() {
    return attribute1;
  }

  public void setAttribute1(String attribute1) {
    this.attribute1 = attribute1;
  }

  public String getAttribute2() {
    return attribute2;
  }

  public void setAttribute2(String attribute2) {
    this.attribute2 = attribute2;
  }

  public String getAttribute3() {
    return attribute3;
  }

  public void setAttribute3(String attribute3) {
    this.attribute3 = attribute3;
  }

  public String getAttribute4() {
    return attribute4;
  }

  public void setAttribute4(String attribute4) {
    this.attribute4 = attribute4;
  }

  public String getAttribute5() {
    return attribute5;
  }

  public void setAttribute5(String attribute5) {
    this.attribute5 = attribute5;
  }

  @Override

  public String toString() {
    return JacksonUtils.toJson(this);
  }

  public String getPurCurrency() {
    return purCurrency;
  }

  public void setPurCurrency(String purCurrency) {
    this.purCurrency = purCurrency;
  }

  public Date getOperateTime() {
    return operateTime;
  }

  public void setOperateTime(Date operateTime) {
    this.operateTime = operateTime;
  }
}
