package com.uas.platform.warehouse.backend.service;

import com.uas.platform.warehouse.backend.entity.*;
import com.uas.platform.warehouse.backend.transport.entity.TransferStatus;

/**
 * Abstract interface for stock-in business.
 *
 * @author huxz
 */
public interface ShipmentService {

  /**
   * Ship from warehouse, Only for api calling.
   *
   * @param shipment  shipment voucher data
   * @return  shipment info
   */
  boolean shipFromWarehouseForApi(Shipment shipment);

  /**
   * Stockin from warehouse, Only for api calling.
   *
   * @param stockin  stockin voucher data
   * @return  stockin info
   */
  boolean stockinFromWarehouseForApi(Stockin stockin);

  /**
   * Transfer from warehouse, Only for api calling.
   *
   * @param transfer  stockin voucher data
   * @return  stockin info
   */
  boolean transferFromWarehouseForApi(Transfer transfer);

  /**
   * Product from enterprise, Only for api calling.
   *
   * @param product  stockin voucher data
   * @return  stockin info
   */
  boolean productFromEnterpriseForApi(Product product);

  /**
   * Reply from warehouse provider, Only for api calling.
   *
   * @param reply normal reply
   * @return  status of operation
   */
  boolean replyFromWarehouse(NormalReply reply);

  /**
   * Packing from warehouse, Only for api calling.
   *
   * @param packing  shipment voucher data
   * @return  shipment info
   */
  boolean packingFromWarehouseForApi(Packing packing);

  /**
   * Invoice from warehouse, Only for api calling.
   *
   * @param invoice  shipment voucher data
   * @return  shipment info
   */
  boolean invoiceFromWarehouseForApi(Invoice invoice);

  /**
   * Reply packing from warehouse provider, Only for api calling.
   *
   * @param packingReply normal reply
   * @return  status of operation
   */
  boolean replyPackingFromWarehouse(PackingReply packingReply);

  /**
   * Reply invoice from warehouse provider, Only for api calling.
   *
   * @param invoiceReply invoice-reply
   * @return  status of operation
   */
  boolean replyInvoiceFromWarehouse(InvoiceReply invoiceReply);

  /**
   * Reply mainfest from warehouse provider, Only for api calling.
   *
   * @param prodiomainfest prodiomainfest-reply
   * @return  reply of prodiomainfest
   */
  boolean replyProdioMainfestFromWarehouse(ProdioMainfest prodiomainfest);

  /**
   * Reply mainfest from warehouse provider, Only for api calling.
   *
   * @param productMainfest productMainfest-reply
   * @return  reply of productMainfest
   */
  boolean replyProductMainfestFromWarehouse(ProductMainfest productMainfest);

  /**
   * Reply fee from warehouse provider, Only for api calling.
   *
   * @param fee fee-reply
   * @return  reply of fee
   */
  boolean replyFeeFromWarehouse(Fee fee);

}
