package com.uas.platform.warehouse.core.common;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import java.io.Serializable;

/**
 * Unified Response Date format.
 *
 * @param <T>
 *   the type of response data
 * @author huxz
 */
@SuppressWarnings("unused")
@JsonInclude(Include.NON_NULL)
public class ResultBean<T> implements Serializable {

  private static final long serialVersionUID = -8666185459443067060L;

  private Boolean success;

  private T data;

  private ErrorCode code;

  private String message;

  enum ErrorCode {

    /**
     * Request occurs errors.
     */
    FAIL,

    /**
     * Request has no permission.
     */
    NO_PERMISSION
  }

  public ResultBean() {
  }

  public ResultBean(T data) {
    this.success = true;
    this.data = data;
  }

  /**
   * response result when error occurs.
   *
   * @param e   exception info
   */
  public ResultBean(Throwable e) {
    this.success = false;
    this.message = e.toString();

    // Set default code
    this.code = ErrorCode.FAIL;
  }

  public Boolean getSuccess() {
    return success;
  }

  public void setSuccess(Boolean success) {
    this.success = success;
  }

  public T getData() {
    return data;
  }

  public void setData(T data) {
    this.data = data;
  }

  public ErrorCode getCode() {
    return code;
  }

  public void setCode(ErrorCode code) {
    this.code = code;
  }

  public String getMessage() {
    return message;
  }

  public void setMessage(String message) {
    this.message = message;
  }

  @Override
  public String toString(){
    return "{sucess:"+this.success+"}";
  }
}
