package com.uas.platform.warehouse.core.util;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.JavaType;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.uas.platform.warehouse.core.JsonConvertException;
import java.io.IOException;
import java.io.Reader;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Jackson Util class.
 *
 * @author huxz
 */
@SuppressWarnings("unused")
public final class JacksonUtils {

  private static final Log logger = LogFactory.getLog(JacksonUtils.class);

  private static final String EMPTY_JSON = "{}";

  private static final String EMPTY_ARRAY = "[]";

  private static ObjectMapper objectMapper;

  /**
   * 把JSON文本parse为JavaBean.
   */
  public static <T> T fromJson(String text, Class<T> clazz) {
    if (objectMapper == null) {
      objectMapper = new ObjectMapper();
    }

    try {
      return objectMapper.readValue(text, clazz);
    } catch (IOException e) {
      throw new JsonConvertException("转换Java对象失败", e);
    }
  }

  /**
   * Parse Json InputStream to Java Bean.
   *
   * @param reader Json InputStream
   * @param clazz Java Bean class
   */
  public static <T> T fromJson(Reader reader, Class<T> clazz) {
    if (reader == null) {
      throw new IllegalArgumentException("InputStream must be not Null");
    }

    if (objectMapper == null) {
      objectMapper = new ObjectMapper();
    }

    try {
      return objectMapper.readValue(reader, clazz);
    } catch (IOException e) {
      throw new JsonConvertException("转换Java对象失败", e);
    }
  }

  /**
   * 把JSON文本parse成JavaBean集合.
   */
  public static <T> List<T> fromJsonArray(String text, Class<T> clazz) {
    if (objectMapper == null) {
      objectMapper = new ObjectMapper();
    }
    JavaType javaType = objectMapper.getTypeFactory()
        .constructParametricType(ArrayList.class, clazz);

    try {
      if (EMPTY_ARRAY.equals(text)) {
        return Collections.emptyList();
      }

      return objectMapper.readValue(text, javaType);
    } catch (IOException e) {
      e.printStackTrace();
      throw new JsonConvertException("转换Java List失败", e);
    }
  }

  /**
   * 将JavaBean序列化为JSON文本.
   */
  public static String toJson(Object object) {
    if (objectMapper == null) {
      objectMapper = new ObjectMapper();
    }

    try {
      return objectMapper.writeValueAsString(object);
    } catch (JsonProcessingException e) {
      throw new JsonConvertException("序列化成Json失败", e);
    }
  }

}
