package com.uas.platform.warehouse.online.api;

import com.alibaba.fastjson.JSON;
import com.uas.platform.warehouse.online.dao.AppAuthenticationDao;
import com.uas.platform.warehouse.online.entity.AppAuthentication;
import com.uas.platform.warehouse.online.util.AppKeyUtil;
import com.uas.platform.warehouse.online.util.HttpUtil;
import com.uas.sso.AuthToken;
import com.uas.sso.SSOConfig;
import com.uas.sso.SSOHelper;
import com.uas.sso.SSOToken;
import org.apache.catalina.servlet4preview.http.HttpServletRequest;
import org.apache.log4j.Logger;
import org.joda.time.DateTime;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.ui.ModelMap;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletResponse;
import java.io.*;

/**
 * Created by luhg on 2017/11/10.
 * User login.
 */
@RestController
public class LoginController{
    private static final Logger logger = Logger.getLogger(HttpUtil.class);

    @Autowired
    private  AppAuthenticationDao authenticationDao;

    @Autowired
    private HttpServletRequest request;
    /**
     * 登录接口
     * @param type 登录类型
     *             user：用户
     *             provider：供应商
     * @return 返回登录代理页面
     */
    @RequestMapping(value = "/login/{type}", method = RequestMethod.GET)
    @ResponseBody
    public ModelAndView login(@PathVariable String type) {
        request.getSession().setAttribute("type", type);
        return new ModelAndView("/views/proxyLogin.html");
    }

    /**
     * 在跨域确认账户中心登录之后调用接口，写入登录cookie
     * @param replyTxt 由账户中心返回的数据
     * @return 设置cookie是否成功
     */
    @RequestMapping(value = "/login/crossAfter", method = RequestMethod.POST)
    @ResponseBody
    public ModelMap getAuthenticationByUUAndType(HttpServletResponse response, String replyTxt){
        if (!StringUtils.isEmpty(replyTxt)) {
            SSOConfig config = SSOHelper.getSSOService().getConfig();
            AuthToken token = SSOHelper.ok(request, response, replyTxt, config.getClientPublicKey(), config.getCenterPublicKey());
            if (token != null) {
                SSOToken tk = new SSOToken();
                tk.setUid(token.getUid());
                tk.setTime(token.getTime());
                String type = String.valueOf(request.getSession().getAttribute("type"));
                AppAuthentication appAuthentication = getAuthenticationByToken(token, type);
                if (appAuthentication == null) {
                    return new ModelMap("error", true);
                }
                tk.setData(JSON.toJSONString(appAuthentication));
                SSOHelper.setSSOCookie(request, response, tk, true);
            }
        }
        return new ModelMap("success", true);
    }

    /**
     * 根据token获得验证
     * @param token
     * @param type
     * @return
     */
    private AppAuthentication getAuthenticationByToken(AuthToken token, String type) {
        AppAuthentication appAuthentication = null;
        if (token.getData() != null) {
            com.uas.account.entity.UserView tokenUser = JSON.parseObject(token.getData(), com.uas.account.entity.UserView.class);
            appAuthentication = authenticationDao.findByEnUu(tokenUser.getSpaceDialectUID());
            if(appAuthentication==null){
                appAuthentication = new AppAuthentication();
                String appKey = AppKeyUtil.createAppKey();
                String secretKey = AppKeyUtil.createSecretKey(appKey);
                appAuthentication.setEnUu(tokenUser.getSpaceDialectUID());
                appAuthentication.setEnName(tokenUser.getSpaceName());
                appAuthentication.setAppKey(appKey);
                appAuthentication.setSecretKey(secretKey);
                appAuthentication.setCreateTime(DateTime.now().toDate());
                appAuthentication.setType(AppAuthentication.IdentificationType.getIdentificationType(type));
                authenticationDao.save(appAuthentication);
                logger.info("创建新用户:"+"企业名称="+tokenUser.getSpaceName()+"&appKey="+appKey+
                        "&secretKey="+secretKey+"&type="+AppAuthentication.IdentificationType.getIdentificationType(type));
            }
        }
        return appAuthentication;
    }

    /**
     * 获取跨域登录的参数
     *
     * @return
     * @throws IOException
     */
    @RequestMapping(value = "/login/crossBefore", method = RequestMethod.GET)
    @ResponseBody
    public ModelMap getCrossLoginData(HttpServletRequest request, HttpServletResponse response) throws IOException {
        ModelMap model = new ModelMap();
        SSOConfig config = SSOHelper.getSSOService().getConfig();
        // 业务系统私钥签名 authToken 自动设置临时会话 cookie 授权后自动销毁
        AuthToken at = SSOHelper.askCiphertext(request, response, config.getClientPrivateKey());
        // askUrl 询问 sso 是否登录地址
        model.addAttribute("askUrl", config.getCrossAskUrl());
        // askTxt 询问 token 密文
        model.addAttribute("askData", at.encryptAuthToken());
        return model;
    }

    /**
     * 判断是否登录
     * @return
     */
    @RequestMapping("/isLogin")
    public ModelMap isLogin() {
        SSOToken token = SSOHelper.getToken(request);
        return new ModelMap("isLogin", token!=null);
    }
}
