package com.uas.platform.warehouse.online.service.impl;

import com.uas.platform.warehouse.online.dao.AppAuthenticationDao;
import com.uas.platform.warehouse.online.entity.AppAuthentication;
import com.uas.platform.warehouse.online.entity.AppAuthentication.IdentificationType;
import com.uas.platform.warehouse.online.service.ApplicationService;
import com.uas.platform.warehouse.online.util.AppKeyUtil;
import org.apache.commons.lang3.Validate;
import org.joda.time.DateTime;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * Java Bean implementations of interface {@code ApplicationService.
 *
 * @author huxz
 */
@Service
public class ApplicationServiceImpl implements ApplicationService {

  private final AppAuthenticationDao authenticationDao;

  @Autowired
  public ApplicationServiceImpl(
      AppAuthenticationDao authenticationDao) {
    this.authenticationDao = authenticationDao;
  }

  @Override
  public AppAuthentication createAuthenticationWhenAgree(AppAuthentication authentication) {
    String type = "当前企业用户";

    Validate.notNull(authentication, "仓储接口认证信息不能为空");
    Validate.notBlank(authentication.getEnUu(), "用户的企业UU不能为空");
    Validate.notNull(authentication.getType(), "用户申请接口类型不能为空");
    if (IdentificationType.ENTERPRISE_USER.equals(authentication.getType())) {
      Validate.notBlank(authentication.getEnName(), "用户的企业名称不能为空");
    } else if (IdentificationType.WAREHOUSE_PROVIDER.equals(authentication.getType())) {
      Validate.notBlank(authentication.getWhName(), "仓储名称不能为空");
      type = "当前仓储提供商";
    } else {
      throw new IllegalArgumentException(String.format("接口类型 %s 不存在",
          authentication.getType()));
    }

    AppAuthentication appAuthentication = authenticationDao
        .findByEnUuAndType(authentication.getEnUu(), authentication.getType());
    if (appAuthentication != null) {
      throw new IllegalStateException(type + "已经申请开发者秘钥");
    }

    String appKey = AppKeyUtil.createAppKey();
    String secretKey = AppKeyUtil.createSecretKey(appKey);
    authentication.setAppKey(appKey);
    authentication.setSecretKey(secretKey);
    authentication.setCreateTime(DateTime.now().toDate());

    authentication.setRemark("test");

    return authenticationDao.save(authentication);
  }
}
