package com.uas.platform.warehouse.online.util;

import java.util.Random;
import java.util.UUID;

/**
 * 用于生成Api accessKey和 secretKey.
 *
 * @author huxz
 */
public class AppKeyUtil {

  private static String createUuid() {
    String uuid = UUID.randomUUID().toString();
    return uuid.replaceAll("-", "");
  }

  /**
   * Create app key, using uuid.
   */
  public static String createAppKey() {
    return createUuid().toLowerCase();
  }

  /**
   * Create secret key based on app key.
   *
   * @param appKey key represents app visitor
   */
  public static String createSecretKey(String appKey) {
    if (appKey == null || "".equals(appKey)) {
      throw new IllegalArgumentException("App Key can't be empty");
    }

    int randomNum = 8;
    StringBuilder builder = new StringBuilder(createUuid());
    for (int i = 0; i < randomNum; i++) {
      Random random = new Random();
      int index = random.nextInt(appKey.length());

      builder.insert(index, appKey.substring(index, index + 1));
    }
    return builder.toString().toUpperCase();
  }
}
