package com.uas.platform.warehouse.backend.transport.auth.entity;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.uas.platform.warehouse.core.util.JacksonUtils;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Index;
import javax.persistence.Table;

/**
 * The type contains app key and secret key.
 *
 * @author huxz
 */
@Entity
@Table(name = "app_key_manage", indexes = {
    @Index(name = "unique_identification", columnList = "en_uu, identify_type", unique = true),
    @Index(name = "index_app_key", columnList = "app_key", unique = true)})
@JsonInclude(Include.NON_EMPTY)
public class AppAuthentication implements Serializable {

  private static final long serialVersionUID = -8727089238707403295L;

  /**
   * primary key.
   */
  @Id
  @GeneratedValue
  @Column(name = "id")
  private Long id;

  /**
   * uu number of enterprise.
   */
  @Column(name = "en_uu")
  private String enUu;

  /**
   * the name of enterprise, required if type set to ENTERPRISE_USER.
   */
  @Column(name = "en_name")
  private String enName;

  /**
   * the name of warehouse, required if type set to WAREHOUSE_PROVIDER.
   */
  @Column(name = "wh_name")
  private String whName;

  /**
   * identifier of the app.
   */
  @Column(name = "app_key")
  private String appKey;

  /**
   * secret key.
   */
  @Column(name = "secret_key")
  private String secretKey;

  /**
   * Represent type of user identification.
   */
  @Enumerated(value = EnumType.STRING)
  @Column(name = "identify_type")
  private IdentificationType type;

  /**
   * time when the key is created.
   */
  @Column(name = "create_time")
  private Date createTime;

  /**
   * Whether the key is usable.
   */
  @Column(name = "enabled")
  private boolean enabled = true;

  /**
   * Remark of a authentication.
   */
  @Column(name = "remark")
  private String remark;

  public AppAuthentication() {
  }

  public Long getId() {
    return id;
  }

  public void setId(Long id) {
    this.id = id;
  }

  public String getEnUu() {
    return enUu;
  }

  public void setEnUu(String enUu) {
    this.enUu = enUu;
  }

  public String getEnName() {
    return enName;
  }

  public void setEnName(String enName) {
    this.enName = enName;
  }

  public String getWhName() {
    return whName;
  }

  public void setWhName(String whName) {
    this.whName = whName;
  }

  public String getAppKey() {
    return appKey;
  }

  public void setAppKey(String appKey) {
    this.appKey = appKey;
  }

  public String getSecretKey() {
    return secretKey;
  }

  public void setSecretKey(String secretKey) {
    this.secretKey = secretKey;
  }

  public IdentificationType getType() {
    return type;
  }

  public void setType(IdentificationType type) {
    this.type = type;
  }

  public Date getCreateTime() {
    return createTime;
  }

  public void setCreateTime(Date createTime) {
    this.createTime = createTime;
  }

  public boolean isEnabled() {
    return enabled;
  }

  public void setEnabled(boolean enabled) {
    this.enabled = enabled;
  }

  public String getRemark() {
    return remark;
  }

  public void setRemark(String remark) {
    this.remark = remark;
  }

  @Override
  public String toString() {
    return JacksonUtils.toJson(this);
  }

  public enum IdentificationType {
    /**
     * Represent enterprise user.
     */
    ENTERPRISE_USER,

    /**
     * Represent warehouse provider.
     */
    WAREHOUSE_PROVIDER
  }
}
