package com.uas.platform.warehouse.backend.transport.dao;

import com.uas.platform.warehouse.backend.transport.entity.Notification;
import com.uas.platform.warehouse.backend.transport.entity.TransferStatus;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.mongodb.repository.MongoRepository;
import org.springframework.stereotype.Repository;

/**
 * Abstract interface for notification database operations.
 *
 * @author huxz
 */
@Repository
public interface NotificationDao extends MongoRepository<Notification, String> {

  /**
   * Paging notification data.
   *
   * @param whName  the name of warehouse
   * @param toBeDownload  voucher type
   * @param pageInfo  the status of notification
   * @return  pagination of notification
   */
  Page<Notification> findByWhNameAndStatus(String whName, TransferStatus toBeDownload, Pageable pageInfo);

  Page<Notification> findByReceiverUUAndStatus(String recevierUU, TransferStatus toBeDownload, Pageable pageInfo);
  /**
   *
   */
  @Override
  Notification findOne(String s);

  /**
   * Paging notification data.
   *
   * @param whEnUu  enterprise uu of warehouse provider
   * @param toBeDownload  voucher type
   * @param pageInfo  status of notification
   * @return  pagination of notification
   */
  Page<Notification> findByWhEnUuAndStatus(String whEnUu, TransferStatus toBeDownload, Pageable pageInfo);
}
