package com.uas.platform.warehouse.backend.transport.dao;

import com.uas.platform.warehouse.backend.transport.entity.PostBack;
import com.uas.platform.warehouse.backend.transport.entity.TransferStatus;
import com.uas.platform.warehouse.core.domain.VoucherType;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.mongodb.repository.MongoRepository;
import org.springframework.stereotype.Repository;

/**
 * Abstract interface for PostBack database operations.
 *
 * @author huxz
 */
@Repository
public interface PostBackDao extends MongoRepository<PostBack, String> {

  /**
   * Paging post back data.
   *
   * @param enUu  uu of a enterprise user
   * @param type  voucher type
   * @param toBeDownload  the status of notification
   * @param pageInfo  pagination information
   * @return  pagination of post back
   */
  Page<PostBack> findByEnUuAndTypeAndStatus(String enUu, VoucherType type,
      TransferStatus toBeDownload, Pageable pageInfo);

  Page<PostBack> findByReceiverUUAndStatus(String receiverUU,
                                            TransferStatus toBeDownload, Pageable pageInfo);

  /**
   * Paging post back data.
   *
   * @param enUu  enterprise uu
   * @param toBeDownload  status of notification
   * @param pageInfo  pagination information
   * @return  pagination of post back
   */
  Page<PostBack> findByEnUuAndStatus(String enUu, TransferStatus toBeDownload, Pageable pageInfo);
}
