package com.uas.platform.warehouse.backend.transport.service.impl;

import com.uas.platform.warehouse.backend.transport.auth.entity.AppAuthentication;
import com.uas.platform.warehouse.backend.transport.dao.NotificationDao;
import com.uas.platform.warehouse.backend.transport.dao.PostBackDao;
import com.uas.platform.warehouse.backend.transport.entity.BaseReply;
import com.uas.platform.warehouse.backend.transport.entity.Notification;
import com.uas.platform.warehouse.backend.transport.entity.PostBack;
import com.uas.platform.warehouse.backend.transport.entity.TransferStatus;
import com.uas.platform.warehouse.backend.transport.service.NotificationService;
import com.uas.platform.warehouse.backend.transport.util.AuthenticationUtil;
import org.apache.commons.lang3.Validate;
import org.apache.log4j.Logger;
import org.joda.time.LocalDateTime;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.UUID;

/**
 * Java Bean implementation of {@code NotificationService}.
 *
 * @author huxz
 */
@Service
public class NotificationServiceImpl implements NotificationService {

  private static final Logger logger = Logger.getLogger(NotificationServiceImpl.class);

  private final NotificationDao notificationDao;

  private final PostBackDao backDao;

  @Autowired
  public NotificationServiceImpl(
      NotificationDao notificationDao,
      PostBackDao backDao) {
    this.notificationDao = notificationDao;
    this.backDao = backDao;
  }

  @Override
  public TransferStatus saveVoucherDataToMongo(Notification notification) {
    Validate.notNull(notification, "单据通知信息不能为空");
    Validate.notBlank(notification.getWhEnUu(), "仓库公司企业UU不能为空");
    Validate.notNull(notification.getVoucher(), "出货单不能为空");

    notification.setStatus(TransferStatus.TO_BE_DOWNLOAD);
    notification.setUploadedTime(LocalDateTime.now().toDate());

    String billId = UUID.randomUUID().toString().replaceAll("-", "");
    notification.setId(billId);
    notification.getVoucher().setBillId(billId);
    notificationDao.save(notification);
    return notification.getStatus();
  }

  @Override
  public TransferStatus replyFromWarehouse(BaseReply reply) {
    Validate.notNull(reply, "出货回传信息不能为空");

    AppAuthentication authentication = AuthenticationUtil.getAuthentication();

    PostBack postBack = new PostBack();
    // Set enterprise info
    postBack.setEnUu(reply.getReceiverUU());
    // Set warehouse provider info
    postBack.setWhEnUu(authentication.getEnUu());
    postBack.setWhName(authentication.getWhName());
    postBack.setStatus(TransferStatus.TO_BE_DOWNLOAD);
    postBack.setUploadedTime(LocalDateTime.now().toDate());
    postBack.setReply(reply);
    // Voucher type is required
    postBack.setType(reply.getType());
    backDao.save(postBack);
    System.out.println(postBack.getStatus());
    return postBack.getStatus();
  }

}
