package com.uas.platform.warehouse.backend.transport.service.impl;

import com.uas.platform.warehouse.backend.transport.auth.entity.AppAuthentication;
import com.uas.platform.warehouse.backend.transport.dao.NotificationDao;
import com.uas.platform.warehouse.backend.transport.dao.PostBackDao;
import com.uas.platform.warehouse.backend.transport.entity.*;
import com.uas.platform.warehouse.backend.transport.service.PullDataService;
import com.uas.platform.warehouse.backend.transport.util.AuthenticationUtil;
import com.uas.platform.warehouse.core.domain.VoucherType;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

/**
 * Java Bean Implementation of {@code PullDataService}.
 *
 * @author huxz
 */
@Service
public class PullDataServiceImpl implements PullDataService {

  private static final Logger logger = Logger.getLogger(NotificationServiceImpl.class);

  private final NotificationDao notificationDao;

  private final PostBackDao postBackDao;

  @Autowired
  public PullDataServiceImpl(NotificationDao notificationDao,
      PostBackDao postBackDao) {
    this.notificationDao = notificationDao;
    this.postBackDao = postBackDao;
  }

  @Override
  @Transactional(rollbackFor = RuntimeException.class)
  public List<BaseVoucher> gainNotificationFromEnterprise(Pageable pageInfo) {

    AppAuthentication authentication = AuthenticationUtil.getAuthentication();
    Page<Notification> voucherPage = notificationDao.findByWhEnUuAndStatus(
            authentication.getEnUu(), TransferStatus.TO_BE_DOWNLOAD, pageInfo);
    if (voucherPage == null || CollectionUtils.isEmpty(voucherPage.getContent())) {
      if (logger.isDebugEnabled()) {
        logger.debug("Not find any shipment");
      }
      return Collections.emptyList();
    }

    List<String> result = new ArrayList<>();
    List<BaseVoucher> vouchers = new ArrayList<>();
    List<Notification> content = voucherPage.getContent();
    for (Notification notification : content) {
      // Update notification status  改为调用状态回传接口更新状态
      // notification.setStatus(TransferStatus.DOWNLOADED);
      // notificationDao.save(notification);

      // Gain json data of voucher
      vouchers.add(notification.getVoucher());
    }
    return vouchers;
  }
  @Override
  @Transactional(rollbackFor = RuntimeException.class)
  public boolean updateStatus(Status status){
    boolean flag = false;
    String billId = status.getBillId();
    Notification notification = notificationDao.findOne(billId);
    Status.BillStatus billStatus = status.getBillStatus();
    if(billStatus.equals(Status.BillStatus.OK)){
      notification.setStatus(TransferStatus.DOWNLOADED);
      notificationDao.save(notification);
      flag = true;
    }
    return flag;
  }
  @Override
  public List<BaseReply> gainReplyNotice(VoucherType type, Pageable pageInfo) {
    // Using Spring Assertion utility class to validate arguments.

    AppAuthentication authentication = AuthenticationUtil.getAuthentication();

    Page<PostBack> voucherPage = postBackDao.findByEnUuAndStatus(
            authentication.getEnUu(), TransferStatus.TO_BE_DOWNLOAD, pageInfo);
    if (voucherPage == null || CollectionUtils.isEmpty(voucherPage.getContent())) {
      if (logger.isDebugEnabled()) {
        logger.debug("Not find any reply");
      }
      return Collections.emptyList();
    }

    List<PostBack> content = voucherPage.getContent();
    List<BaseReply> replys = new ArrayList<>();
    for (PostBack postBack : content) {
      // Update shipment answer status
      postBack.setStatus(TransferStatus.DOWNLOADED);
      replys.add(postBack.getReply());
      postBackDao.save(postBack);
      // Gain data of shipment answer
    }
    return replys;
  }
}
