package com.uas.platform.warehouse.tools.client;

import com.uas.platform.warehouse.core.common.ResultBean;
import com.uas.platform.warehouse.tools.domain.ShipmentReply;
import com.uas.platform.warehouse.core.util.JacksonUtils;
import com.uas.platform.warehouse.tools.domain.AbstractVoucher;
import com.uas.platform.warehouse.tools.domain.Shipment;
import com.uas.platform.warehouse.tools.exception.RequestFailException;
import com.uas.platform.warehouse.tools.util.HttpClientUtil;
import com.uas.platform.warehouse.tools.util.SignUtil;
import com.uas.platform.warehouse.tools.util.UrlUtils;
import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.apache.http.NameValuePair;
import org.apache.http.client.ClientProtocolException;
import org.apache.log4j.Logger;

/**
 * 提供<strong>企业用户</strong>传递单据数据给仓储提供商，以及获取特定单据的回传数据.
 *
 * @author huxz
 */
public class Warehouse extends AbstractClient {

  private static final Logger logger = Logger.getLogger(Warehouse.class);

  /**
   * Url to gain notice reply.
   */
  private static final String GAIN_NOTICE_REPLY = "/api/gain-notice-reply";

  public Warehouse(String host, String appKey, String secretKey) {
    super(host, appKey, secretKey);
  }

  /**
   * 一次获取50条所有仓储服务商出货回传信息.
   */
  public String getReplyNotice()
          throws URISyntaxException, IOException {
    URI uri = UrlUtils.getUriByKeyAndUrl(host,GAIN_NOTICE_REPLY,appKey, secretKey);

    ResultBean resultBean = HttpClientUtil.getMethod(uri);

    if (resultBean == null) {
      throw new ClientProtocolException("Response contains no content");
    } else if (!resultBean.getSuccess()) {
      throw new RequestFailException(resultBean.getMessage());
    }
    // Transform LinkedTreeMap to Voucher Object
    return resultBean.getData().toString();
  }
}
