package com.uas.platform.warehouse.tools.client;

import com.uas.platform.warehouse.core.common.ResultBean;
import com.uas.platform.warehouse.tools.domain.Reply;
import com.uas.platform.warehouse.tools.domain.ShipmentReply;
import com.uas.platform.warehouse.tools.domain.StockInReply;
import com.uas.platform.warehouse.core.util.JacksonUtils;
import com.uas.platform.warehouse.tools.exception.RequestFailException;
import com.uas.platform.warehouse.tools.util.HttpClientUtil;
import com.uas.platform.warehouse.tools.util.SignUtil;
import com.uas.platform.warehouse.tools.util.UrlUtils;
import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.apache.commons.lang3.Validate;
import org.apache.http.NameValuePair;
import org.apache.http.client.ClientProtocolException;
import org.apache.log4j.Logger;

/**
 * 提供<strong>仓储提供商</strong>传递单据回传给企业用户，以及获取特定单据通知数据.
 *
 * @author huxz
 */
public class WarehouseProvider extends AbstractClient {

  private static final Logger logger = Logger.getLogger(WarehouseProvider.class);

  /**
   * Url to gain notice.
   */
  private static final String GAIN_NOTICE = "/api/gain-notice";

  public WarehouseProvider(String host, String appKey, String secretKey) {
    super(host, appKey, secretKey);
  }

  /**
   * 从平台拉取仓储操作通知，每次最多50条.
   */
  @SuppressWarnings("unchecked")
  public String getNotification() throws URISyntaxException, IOException {
    URI uri = UrlUtils.getUriByKeyAndUrl(host,GAIN_NOTICE,appKey, secretKey);

    ResultBean resultBean = HttpClientUtil.getMethod(uri);

    if (resultBean == null) {
      throw new ClientProtocolException("Response contains no content");
    } else if (!resultBean.getSuccess()) {
      throw new RequestFailException(resultBean.getMessage());
    }
    // Transform LinkedTreeMap to Voucher Object
    return resultBean.getData().toString();
  }
}
