package com.uas.platform.warehouse.tools.domain;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.uas.platform.warehouse.core.domain.shipment.ShipCommon;
import com.uas.platform.warehouse.core.util.JacksonUtils;

import java.util.Date;
import java.util.List;

/**
 * 出货单，用于出货通知.
 *
 * @author huxz
 */
@JsonInclude(Include.NON_EMPTY)
public class Shipment extends AbstractVoucher implements ShipCommon {

  private static final long serialVersionUID = -4660447730976425618L;

  /**
   * 单据主键
   */
  @JsonIgnore
  private long id;

  /**
   * 出货单号.
   */
  private String pullNo;

  /**
   * 出货类型.
   */
  private String pullType;

  /**
   * 预出货日期.
   */
  private Date predate;

  /**
   * 仓库地址
   */
  private String location;

  /**
   * 出货库位.
   */
  private String whName;


  /**
   * 客户UU
   */
  private String custUU;


  /**
   * 客户编号.
   */
  private String custCode;

  /**
   * 收货地址.
   */
  private String address;

  /**
   * 联系人地址.
   */
  private String contact;

  /**
   * 装箱单要求.
   */
  private String packRequest;

  /**
   * 发票要求.
   */
  private String invoiceRequest;

  /**
   * 发货说明.
   */
  private String deliveryNote;

  /**
   * 备注.
   */
  private String remark;

  /**
   * 录入人.
   */
  private String operator;

  /**
   * 发票号.
   */
  private String invoiceNo;

  /**
   * 类型，标识是入库还是出货还是其他类型的数据.
   */
  private String type = "pull";

  /**
   * 出货单明细.
   */
  private List<ShipmentDetail> details;

  public Shipment() {
  }

  public String getPullNo() {
    return pullNo;
  }

  public void setPullNo(String pullNo) {
    this.pullNo = pullNo;
  }

  public String getPullType() {
    return pullType;
  }

  public void setPullType(String pullType) {
    this.pullType = pullType;
  }

  public Date getPredate() {
    return predate;
  }

  public void setPredate(Date predate) {
    this.predate = predate;
  }

  public String getWhName() {
    return whName;
  }

  public void setWhName(String whName) {
    this.whName = whName;
  }

  public String getCustCode() {
    return custCode;
  }

  public void setCustCode(String custCode) {
    this.custCode = custCode;
  }

  public String getAddress() {
    return address;
  }

  public void setAddress(String address) {
    this.address = address;
  }

  public String getContact() {
    return contact;
  }

  public void setContact(String contact) {
    this.contact = contact;
  }

  public String getPackRequest() {
    return packRequest;
  }

  public void setPackRequest(String packRequest) {
    this.packRequest = packRequest;
  }

  public String getInvoiceRequest() {
    return invoiceRequest;
  }

  public void setInvoiceRequest(String invoiceRequest) {
    this.invoiceRequest = invoiceRequest;
  }

  public String getDeliveryNote() {
    return deliveryNote;
  }

  public void setDeliveryNote(String deliveryNote) {
    this.deliveryNote = deliveryNote;
  }

  public String getRemark() {
    return remark;
  }

  public void setRemark(String remark) {
    this.remark = remark;
  }

  public String getOperator() {
    return operator;
  }

  public void setOperator(String operator) {
    this.operator = operator;
  }

  public String getInvoiceNo() {
    return invoiceNo;
  }

  public void setInvoiceNo(String invoiceNo) {
    this.invoiceNo = invoiceNo;
  }

  public List<ShipmentDetail> getDetails() {
    return details;
  }

  public void setDetails(List<ShipmentDetail> details) {
    this.details = details;
  }

  @Override
  public String toString() {
    return JacksonUtils.toJson(this);
  }

  public String getLocation() {
    return location;
  }

  public void setLocation(String location) {
    this.location = location;
  }

  public String getCustUU() {
    return custUU;
  }

  public void setCustUU(String custUU) {
    this.custUU = custUU;
  }

  public long getId() {
    return id;
  }

  public void setId(long id) {
    this.id = id;
  }

  public String getType() {
    return type;
  }

  public void setType(String type) {
    this.type = type;
  }
}
