package com.uas.platform.warehouse.tools.domain;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.uas.platform.warehouse.core.domain.VoucherType;
import com.uas.platform.warehouse.core.domain.shipment.ShipCommon;
import com.uas.platform.warehouse.core.util.JacksonUtils;

/**
 * 出货回传.
 *
 * @author huxz
 */
@JsonInclude(Include.NON_EMPTY)
public class ShipmentReply extends AbstractReply implements ShipCommon {

  private static final long serialVersionUID = 951104228730106127L;

  /**
   * 送货单号.
   */
  private String deliverNo;

  /**
   * 出货单号.
   */
  private String pullNo;

  /**
   * 出货状态.
   */
  private PullState state;

  /**
   * 出货类型，与PULL_TYPE一样.
   */
  private String docType;

  /**
   * 仓储操作人.
   */
  private String operator;

  /**
   * 出货回传回复类型.
   */
  public enum PullState {
    /**
     * 表示出货成功状态.
     */
    OK,
    /**
     * 表示出货失败状态.
     */
    NG
  }

  /**
   * 接收方UU
   */
  private String receiverUU;

  /**
   * 发送方UU
   */
  private String senderUU;

  /**
   * 企业名称
   */
  private String enterprise;

  /**
   * 数据类型.
   */
  private String type = "pull-reply";

  private VoucherType voucherType;

  public ShipmentReply() {
  }

  @Override
  public VoucherType getVoucherType(){
    return ShipmentReply.CURRENT_VOUCHER_TYPE;
  }

  public String getDeliverNo() {
    return deliverNo;
  }

  public void setDeliverNo(String deliverNo) {
    this.deliverNo = deliverNo;
  }

  public String getPullNo() {
    return pullNo;
  }

  public void setPullNo(String pullNo) {
    this.pullNo = pullNo;
  }

  public PullState getState() {
    return state;
  }

  public void setState(PullState state) {
    this.state = state;
  }

  public String getDocType() {
    return docType;
  }

  public void setDocType(String docType) {
    this.docType = docType;
  }

  public String getOperator() {
    return operator;
  }

  public void setOperator(String operator) {
    this.operator = operator;
  }

  @Override
  public String getReceiverUU() {
    return receiverUU;
  }

  public void setReceiverUU(String receiverUU) {
    this.receiverUU = receiverUU;
  }

  public String getSenderUU() {
    return senderUU;
  }

  public void setSenderUU(String senderUU) {
    this.senderUU = senderUU;
  }

  public String getEnterprise() {
    return enterprise;
  }

  public void setEnterprise(String enterprise) {
    this.enterprise = enterprise;
  }

  public String getType() {
    return type;
  }

  public void setType(String type) {
    this.type = type;
  }

  public void setVoucherType(VoucherType voucherType) {
    this.voucherType = voucherType;
  }

  @Override
  public String toString() {
    return JacksonUtils.toJson(this);
  }
}
