package com.uas.platform.warehouse.tools.util;

import com.uas.platform.warehouse.core.common.ResultBean;
import com.uas.platform.warehouse.core.util.JacksonUtils;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.net.URI;
import java.nio.charset.Charset;
import java.util.List;
import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.StatusLine;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.HttpResponseException;
import org.apache.http.client.ResponseHandler;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.ContentType;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.log4j.Logger;

/**
 * 使用HttpComponents 实现 http client.
 *
 * @author huxz
 */
public class SslHttpsClientUtil {

  private static final Logger logger = Logger.getLogger(SslHttpsClientUtil.class);

  /**
   * Send GET request to http server.
   *
   * @param uri request uri
   * @return response result of http
   */
  public static ResultBean getMethod(URI uri) throws IOException {
    CloseableHttpClient httpClient = HttpClients.createDefault();
    HttpGet httpGet = new HttpGet(uri);

    return httpClient.execute(httpGet, RESPONSE_HANDLER);
  }

  /**
   * Send POST request to http server.
   *
   * @param uri request uri
   * @param data request body， using json or text format
   * @return response result of http
   */
  public static ResultBean postMethod(URI uri, String data) throws IOException {
    CloseableHttpClient httpClient = HttpClients.createDefault();

    StringEntity entity = new StringEntity(data.toString(), ContentType.APPLICATION_JSON);
    HttpPost httpPost = new HttpPost(uri);
    httpPost.setEntity(entity);

    return httpClient.execute(httpPost, RESPONSE_HANDLER);
  }

  public static <T> ResultBean postMethod(URI uri, List<T> data) throws IOException {
    return postMethod(uri,JacksonUtils.toJson(data));
  }

  private static final ResponseHandler<ResultBean> RESPONSE_HANDLER = new ResponseHandler<ResultBean>() {

    @Override
    public ResultBean handleResponse(final HttpResponse response) throws IOException {
      StatusLine line = response.getStatusLine();
      HttpEntity entity = response.getEntity();

      errorHandler(line,entity);

      ContentType contentType = ContentType.getOrDefault(entity);
      Charset charset = contentType.getCharset();
      Reader reader = new InputStreamReader(entity.getContent(), charset);
      return JacksonUtils.fromJson(reader, ResultBean.class);
    }
  };

  public static void errorHandler( StatusLine line,HttpEntity entity) throws IOException{
    if (line.getStatusCode() >= 300) {
      if (logger.isDebugEnabled()) {
        logger.debug("Response status code: " + line.getStatusCode());
      }

      String errorMessage = Integer.toString(line.getStatusCode());
      if (entity != null) {
        InputStream content = entity.getContent();
        try (ByteArrayOutputStream outputStream = new ByteArrayOutputStream()) {
          byte[] buffer = new byte[1024];
          int len;

          while ((len = content.read(buffer)) >= 0) {
            outputStream.write(buffer, 0, len);
          }
          outputStream.flush();
          errorMessage = outputStream.toString("UTF-8");
        }
      }

      if (logger.isDebugEnabled()) {
        logger.debug("Error Message: " + errorMessage);
      }
      throw new HttpResponseException(line.getStatusCode(), errorMessage);
    }

    if (entity == null) {
      throw new ClientProtocolException("Response contains no content");
    }
  }
}
