package com.uas.platform.warehouse.sample;

import com.uas.platform.warehouse.core.util.JacksonUtils;
import com.uas.platform.warehouse.tools.client.Warehouse;
import com.uas.platform.warehouse.tools.domain.*;
import com.uas.platform.warehouse.tools.util.HttpClientUtil;
import com.uas.platform.warehouse.tools.util.SignUtil;
import com.uas.platform.warehouse.tools.util.UrlUtils;
import org.apache.http.NameValuePair;
import org.joda.time.DateTime;
import org.joda.time.LocalDate;
import org.joda.time.LocalDateTime;
import org.junit.Test;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URI;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by luhg on 2017/11/2.
 */
public class EnterpriseSumaryDemo {
    //private static final String point = "http://218.17.158.219:9443/warehouse/";
    //private static final String point = "192.168.253.12:20320/warehouse/";
    private static final String point = "localhost:20320/";

    private static Warehouse client = new Warehouse(point,
            ConstantForTest.EN_APP_KEY, ConstantForTest.EN_SECRET_KEY);
    /**
     * 测试入库(公共接口)
     * @throws Exception
     */
    @Test
    public void testWarehouseStockinCommonOperations() throws Exception {
        Stockin stockin = EntityDemo.getStockin();
        List<Stockin> stockins = new ArrayList<>();
        stockins.add(stockin);
        String data = JacksonUtils.toJson(stockins);
        boolean res = client.sendToB2b(data);
        System.out.println(res);
    }

    /**
     * 测试出货(公共接口)
     * @throws Exception
     */
    @Test
    public void testWarehouseShipmentCommonOperations() throws Exception {
        Shipment shipment = EntityDemo.getShipment();
        List<Shipment> shipments = new ArrayList<>();
        shipments.add(shipment);
        client.sendToB2b(shipments);
    }

    /**
     * 测试调拨(公共接口)
     * @throws Exception
     */
    @Test
    public void testWarehouseTransferCommonOperations() throws Exception {
        Transfer transfer = EntityDemo.getTransfer();
        List<Transfer> transfers = new ArrayList<>();
        transfers.add(transfer);
        String data = JacksonUtils.toJson(transfers);
        System.out.println("transfer data:");
        System.out.println(data);
        client.sendToB2b(data);
    }

    /**
     * 测试物料(公共接口)
     * @throws Exception
     */
    @Test
    public void testSendProductOperation() throws Exception {
        Product product = EntityDemo.getProduct();
        List<Product> products = new ArrayList<Product>();
        products.add(product);
        boolean msg = client.sendToB2b(products);
        System.out.println("msg");
        System.out.println(msg);
    }

    /**
     * 测试包装单(公共接口)
     * @throws Exception
     */
    @Test
    public void testSendPackingOperation() throws Exception {
        Packing packing = EntityDemo.getPacking();
        List<Packing> packings = new ArrayList<Packing>();
        packings.add(packing);
        boolean msg = client.sendToB2b(packings);
        System.out.println("msg");
        System.out.println(msg);
    }

    /**
     * 测试发票(公共接口)
     * @throws Exception
     */
    @Test
    public void testSendInvoiceOperation() throws Exception {
        Invoice packing = EntityDemo.getInvoice();
        List<Invoice> invoices = new ArrayList<Invoice>();
        invoices.add(packing);
        boolean msg = client.sendToB2b(invoices);
        System.out.println("msg");
        System.out.println(msg);
    }

    /**
     * 测试发票回传(公共接口)
     * @throws Exception
     */
    @Test
    public void testSendInvoiceReplyOperation() throws Exception {
        InvoiceReply invoiceReply = EntityDemo.getInvoiceReply();
        List<InvoiceReply> invoiceReplys = new ArrayList<InvoiceReply>();
        invoiceReplys.add(invoiceReply);
        boolean msg = client.sendToB2b(invoiceReplys);
        System.out.println("msg");
        System.out.println(msg);
    }

    /**
     * 获取供应商回复信息
     * @throws Exception
     */
    @Test
    public void testCustomerGetReplyOperations() throws Exception {
        String data = client.getReplyNotice();
        System.out.println("reply datas:");
        System.out.println(data);
    }

    /**
     * 获取供应商回复信息 MD5
     * @throws Exception
     */
    @Test
    public void testMD5() throws Exception {
        String timestamp = String.valueOf(new DateTime().getMillis());
        String appKey = "0677881a1d5a48dfa3a1e32a7b65e7a5";
        String secretKey = "6E8958941CB53DC48D7B32F4E7DD57C67E54B8FD";
        //String url = "https://218.17.158.219:9443/warehouse//api/warehouse/notice//gain-reply-notice";
        String url = "http://localhost:20320/api/gain-notice-reply";

        String sign = SignUtil.getMD5(appKey + timestamp + secretKey + "md5");
        System.out.println("sign:" + sign);

        String params = "";
        params += "?appKey=" + appKey;              									 			//secretId
        params += "&timestamp=" + timestamp;       								 			//时间戳
        params += "&sign=" + sign;

        url += params;

        System.out.println("url:");
        System.out.println(url);

        httpGetMethod(url);

        //String data = client.getReplyNotice();
        System.out.println("reply datas:");
        //System.out.println(data);
    }

    public void httpGetMethod(String url){
        //String uid
        StringBuilder json = new StringBuilder();

        try {
            URL oracle = new URL(url);
            HttpURLConnection yc = (HttpURLConnection)oracle.openConnection();
            yc.setRequestMethod("GET");
            yc.setRequestProperty("Content-type", "application/json;charset=UTF-8");
            yc.setRequestProperty("Accept-Encoding","gzip,deflate");

            yc.setDoOutput(true);
            yc.setDoInput(true);
            PrintWriter printWriter = new PrintWriter(yc.getOutputStream());
            printWriter.flush();

            yc.setConnectTimeout(6000); 										 //毫秒
            yc.setReadTimeout(6000); 											 //毫秒
            BufferedReader in = new BufferedReader(new InputStreamReader(yc.getInputStream()));
            String inputLine = null;
            while ( (inputLine = in.readLine()) != null) {
                json.append(inputLine);
            }
            in.close();
        } catch (MalformedURLException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
        System.out.println("reponse data;");
        System.out.println(json);
        //return json.toString();
    }
}
