package com.uas.platform.warehouse.sample;

import static com.uas.platform.warehouse.sample.ConstantForTest.ENDPOINT;

import com.uas.platform.warehouse.tools.domain.ShipmentReply;
import com.uas.platform.warehouse.tools.domain.Status;
import com.uas.platform.warehouse.tools.domain.StockInReply;
import com.uas.platform.warehouse.core.util.JacksonUtils;
import com.uas.platform.warehouse.tools.client.WarehouseProvider;
import com.uas.platform.warehouse.tools.domain.NormalReply;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URISyntaxException;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;

import com.uas.platform.warehouse.tools.util.SignUtil;
import org.joda.time.DateTime;
import org.junit.Test;

/**
 * Created by luhg on 2017/11/2.
 */
public class WarehouseProviderSumDemo {
    private static final String point = "localhost:20320/";

    private static WarehouseProvider client = new WarehouseProvider(point,
            ConstantForTest.WH_APP_KEY, ConstantForTest.WH_SECRET_KEY);
    /**
     * 仓库获取单据数据.
     */
    @Test
    public void getNotice() throws IOException, URISyntaxException {
        String notices = client.getNotification();

        System.out.println(" Notice: " + notices);
        //return shipments;
    }

    /**
     * 测试仓库出货回复
     * @throws Exception
     */
    @Test
    public void testProviderReplyOperations() throws Exception {
        ShipmentReply shipmentReply = EntityDemo.getShipmentReply();
        List<ShipmentReply> shipmentReplys = new ArrayList<>();
        shipmentReplys.add(shipmentReply);
        String data = JacksonUtils.toJson(shipmentReplys);
        client.sendToB2b(data);
    }

    /**
     * 测试供应商入库回复
     * @throws Exception
     */
    @Test
    public void testProviderStockinReplyOperations() throws Exception {
        StockInReply stockinReply = EntityDemo.getStockinReply();
        List<StockInReply> stockinReplys = new ArrayList<>();
        stockinReplys.add(stockinReply);
        String data = JacksonUtils.toJson(stockinReplys);
        client.sendToB2b(data);
    }


    /**
     * 通用回复
     */
    @Test
    public void testCommonReplyOperations() throws Exception{
        NormalReply reply = EntityDemo.getNormalReply();
        List<NormalReply> replys = new ArrayList<>();
        replys.add(reply);
        System.out.println(replys);
        client.sendToB2b(replys);
    }

    /**
     *更新状态
     */
    @Test
    public void testUpdateStatus() throws Exception{
        Status status = EntityDemo.getStatus();
        List<Status> statuses = new ArrayList<>();
        statuses.add(status);
        System.out.println(statuses);

        String data = JacksonUtils.toJson(statuses);
        client.updateStatus(data);
    }

    /**
     * 获取供应商回复信息 MD5
     * @throws Exception
     */
    @Test
    public void testMD5() throws Exception {
        String timestamp = String.valueOf(new DateTime().getMillis());
        String appKey = "a16b54ce9b5a45b49532a8309dc9f213";
        String secretKey = "A2564D54734F2A54C0E9AD8134C24F0C135AF126";
        //String url = "https://218.17.158.219:9443/warehouse//api/warehouse/notice//gain-reply-notice";
        String url = "http://localhost:20320/api/gain-notice";
        String sign = SignUtil.getMD5(appKey + timestamp + secretKey );
        System.out.println("sign:" + sign);

        String params = "";
        params += "?appKey=" + appKey;              									 			//secretId
        params += "&timestamp=" + timestamp;       								 			//时间戳
        params += "&sign=" + sign;

        url += params;

        System.out.println("url:");
        System.out.println(url);

        httpGetMethod(url);

        //String data = client.getReplyNotice();
        System.out.println("reply datas:");
        //System.out.println(data);
    }

    public void httpGetMethod(String url){
        //String uid
        StringBuilder json = new StringBuilder();

        try {
            URL oracle = new URL(url);
            HttpURLConnection yc = (HttpURLConnection)oracle.openConnection();
            yc.setRequestMethod("POST");
            yc.setRequestProperty("Content-type", "application/xml;charset=UTF-8");

            yc.setDoOutput(true);
            yc.setDoInput(true);
            PrintWriter printWriter = new PrintWriter(yc.getOutputStream());
            printWriter.flush();

            yc.setConnectTimeout(6000); 										 //毫秒
            yc.setReadTimeout(6000); 											 //毫秒
            BufferedReader in = new BufferedReader(new InputStreamReader(yc.getInputStream()));
            String inputLine = null;
            while ( (inputLine = in.readLine()) != null) {
                json.append(inputLine);
            }
            in.close();
        } catch (MalformedURLException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
        System.out.println("reponse data;");
        System.out.println(json);
        //return json.toString();
    }
}
